@@ -5,15 +5,12 @@ import threading
 import time
 
 import six
-from requests.adapters import HTTPAdapter
 
-from requests.packages.urllib3 import Retry
-
-from sevenbridges.http.client import generate_session
 from sevenbridges.decorators import retry
 from sevenbridges.errors import SbgError
-from sevenbridges.transfer.utils import Progress, total_parts
+from sevenbridges.http.client import generate_session
 from sevenbridges.models.enums import PartSize, TransferState
+from sevenbridges.transfer.utils import Progress, total_parts
 
 
 def _get_part_url(api, url, upload, part):
@@ -86,7 +83,7 @@ def _submit_part(session, url, part, timeout):
 def _upload_part(api, session, url, upload, part_number, part, retry_count,
                  timeout):
     """
-    Userd by the worker to upload a part to the storage service.
+    Used by the worker to upload a part to the storage service.
     :param api: Api instance.
     :param session: Storage service session.
     :param url: Part url.
@@ -258,6 +255,8 @@ class Upload(threading.Thread):
         self._project = project
         self._file_path = file_path
         self._file_size = os.path.getsize(self._file_path)
+        if self._file_size == 0:
+            raise SbgError('File size must not be 0.')
 
         self._verify_file_size()
         self._verify_part_size()
@@ -277,12 +276,7 @@ class Upload(threading.Thread):
         self._stop_signal = False
         self._result = None
 
-        adapter = HTTPAdapter(max_retries=Retry(
-            total=self._retry, status_forcelist=[500, 503], backoff_factor=0.1)
-        )
-        self.session = generate_session(
-            'https://', adapter, self._api.session.proxies
-        )
+        self.session = generate_session(self._api.session.proxies)
 
     def __repr__(self):
         return six.text_type(
@@ -367,6 +361,7 @@ class Upload(threading.Thread):
                 self._URL['upload_complete'].format(upload_id=self._upload_id)
             ).json()
             self._result = File(api=self._api, **response)
+            self._status = TransferState.COMPLETED
 
         except SbgError as e:
             self._status = TransferState.FAILED
@@ -402,7 +397,7 @@ class Upload(threading.Thread):
 
     @property
     def duration(self):
-        return time.time() - self._time_started
+        return (time.time() - self._time_started) * 1000
 
     @property
     def file_name(self):
@@ -444,9 +439,10 @@ class Upload(threading.Thread):
         :raises SbgError: If upload is not in PAUSED or RUNNING state.
         """
         if self.status in (TransferState.PAUSED, TransferState.RUNNING):
-            self._running.set()
+            self._running.clear()
             self._stop_signal = True
             self.join()
+            self._abort_upload()
             self._status = TransferState.STOPPED
             if self._callback:
                 return self._callback(self._status)
@@ -466,19 +462,6 @@ class Upload(threading.Thread):
         else:
             raise SbgError('Can not resume. Upload not in PAUSED state.')
 
-    def abort(self):
-        """
-        Aborts the upload.
-        :raises SbgError: If upload is not in RUNNING state.
-        """
-        if self._status == TransferState.RUNNING:
-            self._stop_signal = True
-            self.join()
-            self._abort_upload()
-            self._status = TransferState.ABORTED
-        else:
-            raise SbgError('Nothing to abort. Upload not in RUNNING state.')
-
     def wait(self):
         """
         Blocks until upload is completed.
@@ -491,10 +474,7 @@ class Upload(threading.Thread):
         :raises SbgError: If upload is not in PREPARING state.
         """
         if self._status == TransferState.PREPARING:
-            self._running.set()
             super(Upload, self).start()
-            self._status = TransferState.RUNNING
-            self._time_started = time.time()
         else:
             raise SbgError(
                 'Unable to start. Upload not in PREPARING state.'
@@ -504,10 +484,9 @@ class Upload(threading.Thread):
         """
         Runs the thread! Should not be used use start() method instead.
         """
-        if self._status != TransferState.PREPARING:
-            raise SbgError(
-                'Can not start. Upload not in PREPARING state.'
-            )
+        self._running.set()
+        self._status = TransferState.RUNNING
+        self._time_started = time.time()
 
         # Initializes the upload
         self._initialize_upload()
